==> gecko-sharp-0.6-i486-1zQs.tgz: usr/src/gecko-sharp-0.6/build-gecko-sharp.sh <==
#!/bin/sh
# Heavily based on the Slackware 10.2 SlackBuild
# written by Zeqadious

# gecko-sharp
# DEPENDENCIES: 

# Verify script is being run by root
if [ "$(id -u)" != "0" ]; then
	echo "This script must be run as root!"
	exit
fi

# Echo the instructions on how to use...
if [ "$1" = "" ]; then
	echo "Zenwalk build-gecko-sharp.sh script: "
	echo "		--cleanup		Cleanup of Post build and Temporary Repo"
	echo "		--desktop		Installs .desktop file if provided"
	echo "		--nocleanup		Performs build with no cleanup"
	exit
fi

# Set the Temporary Build Directory
CWD=`pwd`
if ["$TMP" = ""]; then
	TMP=/tmp
fi

# Package Credentials
NAME=gecko-sharp
PKG=$TMP/package-$NAME
VERSION=0.6
SUBVER=
TARGET=i486
ARCH=${ARCH:-i486}
BUILD=1zQs

# Location of final Package
REPO=/packages

# Use this section if a slack-desc is not already provided in the Working Directory
if [ ! -f $CWD/slack-desc ]; then
cat > $CWD/slack-desc << "EOF"
#          |-----handy-ruler------------------------------------------------------|
gecko-sharp: gecko-sharp
gecko-sharp:
gecko-sharp: Mono bindings for Gecko.
gecko-sharp: 
gecko-sharp: Created for: Zenwalk
EOF
fi

# If --desktop is requested, do
if [ "$1" = "--desktop" -o "$2" = "--desktop" ]; then
	if [ -f $CWD/$NAME.desktop ]; then
		mkdir -p $PKG/usr/share/applications
		cp $CWD/$NAME.desktop $PKG/usr/share/applications
	else
		mkdir -p $PKG/usr/share/applications
		cat > $PKG/usr/share/applications/$NAME.desktop << "EOF"
[Desktop Entry]
Name=
Comment=
Exec=
Icon=
MimeType=
Categories=
Terminal=false
Type=Application
Encoding=UTF-8
EOF
	fi
fi

# Setup Machine Specific compile options
if [ "$ARCH" = "i486" ]; then
	SLKCFLAGS="-O2 -march=i486 -mtune=i686"
elif [ "$ARCH" = "i686" ]; then
	SLKCFLAGS="-O2 -march=i686 -mtune=i686"
elif [ "$ARCH" = "x86_64" ]; then
	SLKCFLAGS="-O2"
fi

# Check and build Temporary Build locations
if [ ! -d $TMP ]; then
	mkdir -p $TMP
fi
if [ ! -d $PKG ]; then
	mkdir -p $PKG
fi

# UnCompress the initial Package
cd $TMP
if [ -f $CWD/$NAME-$VERSION$SUBVER.tar.gz ]; then
	tar xzvf $CWD/$NAME-$VERSION$SUBVER.tar.gz
elif [ -f $CWD/$NAME-$VERSION$SUBVER.tar.bz2 ]; then
	tar jxvf $CWD/$NAME-$VERSION$SUBVER.tar.bz2
elif [ -f $CWD/$NAME-$VERSION$SUBVER.tgz ]; then
	tar zxvf $CWD/$NAME-$VERSION$SUBVER.tgz
elif [ -f $CWD/$NAME-$VERSION$SUBVER.zip ]; then
	unzip -o $CWD/$NAME-$VERSION$SUBVER.zip
fi

# Verify the correct permissions for build
cd $NAME-$VERSION$SUBVER
find . -perm 777 -exec chmod 755 {} \;
chown -R root.root .

# Begin Compile
CFLAGS="$SLKCFLAGS" \
CXXFLAGS="$SLKCFLAGS" \
./configure --prefix=/usr \
--program-prefix="" \
--program-suffix="" \
$TARGET-slackware-linux

make

# Put finished build into Temporary Repo for Packaging
make install DESTDIR=$PKG

# Strip libraries and binaries
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "current ar archive" | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Gzip man pages
find $PKG/usr/man -type f -exec gzip -9f {} \;

# Copy Documentation
mkdir -p $PKG/install
cp $CWD/slack-desc $PKG/install
mkdir -p $PKG/usr/src/$NAME-$VERSION$SUBVER
cp -a $CWD/build-$NAME.sh $PKG/usr/src/$NAME-$VERSION$SUBVER

# If the Package doesn't provide a pixmap image for itself, then copy a Manually provided one
if [ -f $CWD/$NAME.png ]; then
	mkdir -p $PKG/usr/share/pixmaps
	cp $CWD/$NAME.png $PKG/usr/share/pixmaps
elif [ -f $CWD/$NAME.xpm ]; then
	mkdir -p $PKG/usr/share/pixmaps
	cp $CWD/$NAME.xpm $PKG/usr/share/pixmaps
elif [ -f $CWD/$NAME.svg ]; then
	mkdir -p $PKG/usr/share/pixmaps
	cp $CWD/$NAME.svg $PKG/usr/share/pixmaps
fi

# Set appropriate ownerships and permissions
chown -R root:root $PKG
chown -R root:bin $PKG/usr/bin
cd $PKG
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Build the final Package in the Final Repository and provide the md5 checksum
cd $PKG
if [ ! -d $REPO ]; then
	mkdir -p $REPO
fi
makepkg -l y -c n $REPO/$NAME-$VERSION$SUBVER-$ARCH-$BUILD.tgz
md5sum $REPO/$NAME-$VERSION$SUBVER-$ARCH-$BUILD.tgz > $REPO/$NAME-$VERSION$SUBVER-$ARCH-$BUILD.tgz.md5

# Cleanup
if [ "$1" = "--cleanup" -o "$2" = "--cleanup" ]; then
	rm -rf $TMP/$NAME-$VERSION$SUBVER
	rm -rf $PKG
fi

# No Cleanup
if [ "$1" = "--nocleanup" -o "$2" = "--nocleanup" ]; then
	exit
fi

==> gecko-sharp-2.0.0.11-i486-1zQs.tgz: usr/src/gecko-sharp-2.0.0.11/build-gecko-sharp.sh <==
#!/bin/sh
# Heavily based on the Slackware 10.2 SlackBuild
# written by Zeqadious

# gecko-sharp
# DEPENDENCIES: 

# Verify script is being run by root
if [ "$(id -u)" != "0" ]; then
	echo "This script must be run as root!"
	exit
fi

# Echo the instructions on how to use...
if [ "$1" = "" ]; then
	echo "Zenwalk build-gecko-sharp.sh script: "
	echo "		--cleanup		Cleanup of Post build and Temporary Repo"
	echo "		--desktop		Installs .desktop file if provided"
	echo "		--nocleanup		Performs build with no cleanup"
	exit
fi

# Set the Temporary Build Directory
CWD=`pwd`
if ["$TMP" = ""]; then
	TMP=/tmp
fi

# Package Credentials
NAME=gecko-sharp
PKG=$TMP/package-$NAME
VERSION=2.0
SUBVER=0.11
TARGET=i486
ARCH=${ARCH:-i486}
BUILD=1zQs

# Location of final Package
REPO=/packages

# Use this section if a slack-desc is not already provided in the Working Directory
if [ ! -f $CWD/slack-desc ]; then
cat > $CWD/slack-desc << "EOF"
#          |-----handy-ruler------------------------------------------------------|
gecko-sharp: gecko-sharp
gecko-sharp:
gecko-sharp: Mono bindings for Gecko.
gecko-sharp: 
gecko-sharp: Created for: Zenwalk
EOF
fi

# If --desktop is requested, do
if [ "$1" = "--desktop" -o "$2" = "--desktop" ]; then
	if [ -f $CWD/$NAME.desktop ]; then
		mkdir -p $PKG/usr/share/applications
		cp $CWD/$NAME.desktop $PKG/usr/share/applications
	else
		mkdir -p $PKG/usr/share/applications
		cat > $PKG/usr/share/applications/$NAME.desktop << "EOF"
[Desktop Entry]
Name=
Comment=
Exec=
Icon=
MimeType=
Categories=
Terminal=false
Type=Application
Encoding=UTF-8
EOF
	fi
fi

# Setup Machine Specific compile options
if [ "$ARCH" = "i486" ]; then
	SLKCFLAGS="-O2 -march=i486 -mtune=i686"
elif [ "$ARCH" = "i686" ]; then
	SLKCFLAGS="-O2 -march=i686 -mtune=i686"
elif [ "$ARCH" = "x86_64" ]; then
	SLKCFLAGS="-O2"
fi

# Check and build Temporary Build locations
if [ ! -d $TMP ]; then
	mkdir -p $TMP
fi
if [ ! -d $PKG ]; then
	mkdir -p $PKG
fi

# UnCompress the initial Package
cd $TMP
if [ -f $CWD/$NAME-$VERSION-$SUBVER.tar.gz ]; then
	tar xzvf $CWD/$NAME-$VERSION-$SUBVER.tar.gz
elif [ -f $CWD/$NAME-$VERSION-$SUBVER.tar.bz2 ]; then
	tar jxvf $CWD/$NAME-$VERSION-$SUBVER.tar.bz2
elif [ -f $CWD/$NAME-$VERSION-$SUBVER.tgz ]; then
	tar zxvf $CWD/$NAME-$VERSION-$SUBVER.tgz
elif [ -f $CWD/$NAME-$VERSION-$SUBVER.zip ]; then
	unzip -o $CWD/$NAME-$VERSION-$SUBVER.zip
fi

# Verify the correct permissions for build
cd $NAME-$VERSION-$SUBVER
find . -perm 777 -exec chmod 755 {} \;
chown -R root.root .

# Begin Compile
CFLAGS="$SLKCFLAGS" \
CXXFLAGS="$SLKCFLAGS" \
./configure --prefix=/usr \
--program-prefix="" \
--program-suffix="" \
$TARGET-slackware-linux

make

# Put finished build into Temporary Repo for Packaging
make install DESTDIR=$PKG

# Strip libraries and binaries
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "current ar archive" | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Gzip man pages
find $PKG/usr/man -type f -exec gzip -9f {} \;

# Copy Documentation
mkdir -p $PKG/install
cp $CWD/slack-desc $PKG/install
mkdir -p $PKG/usr/src/$NAME-$VERSION.$SUBVER
cp -a $CWD/build-$NAME.sh $PKG/usr/src/$NAME-$VERSION.$SUBVER

# If the Package doesn't provide a pixmap image for itself, then copy a Manually provided one
if [ -f $CWD/$NAME.png ]; then
	mkdir -p $PKG/usr/share/pixmaps
	cp $CWD/$NAME.png $PKG/usr/share/pixmaps
elif [ -f $CWD/$NAME.xpm ]; then
	mkdir -p $PKG/usr/share/pixmaps
	cp $CWD/$NAME.xpm $PKG/usr/share/pixmaps
elif [ -f $CWD/$NAME.svg ]; then
	mkdir -p $PKG/usr/share/pixmaps
	cp $CWD/$NAME.svg $PKG/usr/share/pixmaps
fi

# Set appropriate ownerships and permissions
chown -R root:root $PKG
chown -R root:bin $PKG/usr/bin
cd $PKG
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Build the final Package in the Final Repository and provide the md5 checksum
cd $PKG
if [ ! -d $REPO ]; then
	mkdir -p $REPO
fi
makepkg -l y -c n $REPO/$NAME-$VERSION.$SUBVER-$ARCH-$BUILD.tgz
md5sum $REPO/$NAME-$VERSION.$SUBVER-$ARCH-$BUILD.tgz > $REPO/$NAME-$VERSION.$SUBVER-$ARCH-$BUILD.tgz.md5

# Cleanup
if [ "$1" = "--cleanup" -o "$2" = "--cleanup" ]; then
	rm -rf $TMP/$NAME-$VERSION-$SUBVER
	rm -rf $PKG
fi

# No Cleanup
if [ "$1" = "--nocleanup" -o "$2" = "--nocleanup" ]; then
	exit
fi
